@@ -50,6 +50,6 @@ void fatal(const char *format, ...)
 	}
 
 
-	printf("Fatal error - exiting\n");
+	fprintf(stderr, "Fatal error - exiting\n");
 	exit(1);
 }
